Index: branches/pap/ippToPsps/src/ippToPsps.h
===================================================================
--- branches/pap/ippToPsps/src/ippToPsps.h	(revision 28498)
+++ branches/pap/ippToPsps/src/ippToPsps.h	(revision 28534)
@@ -15,4 +15,6 @@
 #include <dvo_util.h>
 #include "ippToPspsConfig.h"
+#include <libxml/parser.h>
+#include <libxml/tree.h>
 
 #define MAXDETECT 30000 //TODO limit ok?
@@ -20,20 +22,20 @@
 typedef struct {
 
-    uint32_t expId;            // the exposure ID to be used
-    psString expName;          // the exposure name
-    psString surveyType;       // the survey type, eg 3PI, MD01, STS, SSS
-    uint8_t batchType;         // PSPS batch type
-    psString fitsInPath;       // path to FITS input
-    psString resultsPath;      // path to results file
-    FILE* resultsFile;         // file for results  
-    uint16_t numOfInputFiles;  // number of input files
-    char** inputFiles;         // array of input file names
-    psString fitsOutPath;      // path to FITS output
-    fitsfile *fitsOut;         // output FITS file
-    psString configsDir;       // path to IPP/PSPS mapping file
-    pmConfig* pmconfig;        // pmConfig
-    dvoConfig* dvoConfig;      // dvo database
-    IppToPspsConfig* config;   // config structure
-    int exitCode;              // ps exit code
+    uint32_t expId;             // the exposure ID to be used
+    psString expName;           // the exposure name
+    psString surveyType;        // the survey type, eg 3PI, MD01, STS, SSS
+    uint8_t batchType;          // PSPS batch type
+    psString fitsInPath;        // path to FITS input
+    psString resultsPath;       // path to results file
+    xmlDocPtr resultsXmlDoc;    // pointer to XML document for results
+    uint16_t numOfInputFiles;   // number of input files
+    char** inputFiles;          // array of input file names
+    psString fitsOutPath;       // path to FITS output
+    fitsfile *fitsOut;          // output FITS file
+    psString configsDir;        // path to IPP/PSPS mapping file
+    pmConfig* pmconfig;         // pmConfig
+    dvoConfig* dvoConfig;       // dvo database
+    IppToPspsConfig* config;    // config structure
+    int exitCode;               // ps exit code
 
     int (*run)();
